from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.AllJoyn
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
QCC_TRUE: UInt32 = 1
QCC_FALSE: UInt32 = 0
ALLJOYN_MESSAGE_FLAG_NO_REPLY_EXPECTED: UInt32 = 1
ALLJOYN_MESSAGE_FLAG_AUTO_START: UInt32 = 2
ALLJOYN_MESSAGE_FLAG_ALLOW_REMOTE_MSG: UInt32 = 4
ALLJOYN_MESSAGE_FLAG_SESSIONLESS: UInt32 = 16
ALLJOYN_MESSAGE_FLAG_GLOBAL_BROADCAST: UInt32 = 32
ALLJOYN_MESSAGE_FLAG_ENCRYPTED: UInt32 = 128
ALLJOYN_TRAFFIC_TYPE_MESSAGES: UInt32 = 1
ALLJOYN_TRAFFIC_TYPE_RAW_UNRELIABLE: UInt32 = 2
ALLJOYN_TRAFFIC_TYPE_RAW_RELIABLE: UInt32 = 4
ALLJOYN_PROXIMITY_ANY: UInt32 = 255
ALLJOYN_PROXIMITY_PHYSICAL: UInt32 = 1
ALLJOYN_PROXIMITY_NETWORK: UInt32 = 2
ALLJOYN_NAMED_PIPE_CONNECT_SPEC: String = 'npipe:'
ALLJOYN_READ_READY: UInt32 = 1
ALLJOYN_WRITE_READY: UInt32 = 2
ALLJOYN_DISCONNECTED: UInt32 = 4
ALLJOYN_LITTLE_ENDIAN: Byte = 108
ALLJOYN_BIG_ENDIAN: Byte = 66
ALLJOYN_MESSAGE_DEFAULT_TIMEOUT: UInt32 = 25000
ALLJOYN_CRED_PASSWORD: UInt16 = 1
ALLJOYN_CRED_USER_NAME: UInt16 = 2
ALLJOYN_CRED_CERT_CHAIN: UInt16 = 4
ALLJOYN_CRED_PRIVATE_KEY: UInt16 = 8
ALLJOYN_CRED_LOGON_ENTRY: UInt16 = 16
ALLJOYN_CRED_EXPIRATION: UInt16 = 32
ALLJOYN_CRED_NEW_PASSWORD: UInt16 = 4097
ALLJOYN_CRED_ONE_TIME_PWD: UInt16 = 8193
ALLJOYN_PROP_ACCESS_READ: Byte = 1
ALLJOYN_PROP_ACCESS_WRITE: Byte = 2
ALLJOYN_PROP_ACCESS_RW: Byte = 3
ALLJOYN_MEMBER_ANNOTATE_NO_REPLY: Byte = 1
ALLJOYN_MEMBER_ANNOTATE_DEPRECATED: Byte = 2
ALLJOYN_MEMBER_ANNOTATE_SESSIONCAST: Byte = 4
ALLJOYN_MEMBER_ANNOTATE_SESSIONLESS: Byte = 8
ALLJOYN_MEMBER_ANNOTATE_UNICAST: Byte = 16
ALLJOYN_MEMBER_ANNOTATE_GLOBAL_BROADCAST: Byte = 32
@winfunctype('MSAJApi.dll')
def AllJoynConnectToBus(connectionSpec: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('MSAJApi.dll')
def AllJoynCloseBusHandle(busHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSAJApi.dll')
def AllJoynSendToBus(connectedBusHandle: win32more.Windows.Win32.Foundation.HANDLE, buffer: VoidPtr, bytesToWrite: UInt32, bytesTransferred: POINTER(UInt32), reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSAJApi.dll')
def AllJoynReceiveFromBus(connectedBusHandle: win32more.Windows.Win32.Foundation.HANDLE, buffer: VoidPtr, bytesToRead: UInt32, bytesTransferred: POINTER(UInt32), reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSAJApi.dll')
def AllJoynEventSelect(connectedBusHandle: win32more.Windows.Win32.Foundation.HANDLE, eventHandle: win32more.Windows.Win32.Foundation.HANDLE, eventTypes: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSAJApi.dll')
def AllJoynEnumEvents(connectedBusHandle: win32more.Windows.Win32.Foundation.HANDLE, eventToReset: win32more.Windows.Win32.Foundation.HANDLE, eventTypes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSAJApi.dll')
def AllJoynCreateBus(outBufferSize: UInt32, inBufferSize: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('MSAJApi.dll')
def AllJoynAcceptBusConnection(serverBusHandle: win32more.Windows.Win32.Foundation.HANDLE, abortEvent: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_unity_deferred_callbacks_process() -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_unity_set_deferred_callback_mainthread_only(mainthread_only: Int32) -> Void: ...
@winfunctype('MSAJApi.dll')
def QCC_StatusText(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_create() -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_create_and_set(signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_destroy(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_array_create(size: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_array_element(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, index: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_set(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_get(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_copy(source: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_clone(destination: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, source: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_equal(lhv: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, rhv: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Int32: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_array_set(args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: POINTER(UIntPtr), signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_array_get(args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_tostring(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr, indent: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_array_tostring(args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr, indent: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_signature(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_array_signature(values: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numValues: UIntPtr, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_hassignature(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, signature: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_getdictelement(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, elemSig: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_gettype(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_clear(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_stabilize(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_array_set_offset(args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, argOffset: UIntPtr, numArgs: POINTER(UIntPtr), signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_msgarg_set_and_stabilize(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint8(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, y: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_bool(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, b: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int16(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, n: Int16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint16(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, q: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int32(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, i: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint32(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, u: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int64(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, x: Int64) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint64(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, t: UInt64) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_double(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, d: Double) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_string(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, s: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_objectpath(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, o: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_signature(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, g: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint8(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, y: POINTER(Byte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_bool(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, b: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int16(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, n: POINTER(Int16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint16(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, q: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int32(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, i: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint32(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, u: POINTER(UInt32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int64(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, x: POINTER(Int64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint64(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, t: POINTER(UInt64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_double(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, d: POINTER(Double)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_string(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, s: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_objectpath(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, o: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_signature(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, g: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_variant(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, v: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint8_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ay: POINTER(Byte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_bool_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ab: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int16_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, an: POINTER(Int16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint16_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, aq: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int32_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ai: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint32_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, au: POINTER(UInt32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_int64_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ax: POINTER(Int64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_uint64_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, at: POINTER(UInt64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_double_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ad: POINTER(Double)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_string_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, as_: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_objectpath_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ao: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_set_signature_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: UIntPtr, ag: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint8_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), ay: POINTER(Byte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_bool_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), ab: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int16_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), an: POINTER(Int16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint16_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), aq: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int32_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), ai: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint32_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), au: POINTER(UInt32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_int64_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), ax: POINTER(Int64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_uint64_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), at: POINTER(UInt64)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_double_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, length: POINTER(UIntPtr), ad: POINTER(Double)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_variant_array(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, signature: win32more.Windows.Win32.Foundation.PSTR, length: POINTER(UIntPtr), av: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_array_numberofelements(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_array_element(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, index: UIntPtr, element: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_get_array_elementsignature(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, index: UIntPtr) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_getkey(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_getvalue(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_setdictentry(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, key: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_setstruct(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, struct_members: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, num_members: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_getnummembers(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_msgarg_getmember(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, index: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_create_empty() -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_create(defaultLanguage: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_create_full(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_destroy(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_createfromxml(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, aboutDataXml: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_isvalid(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, language: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_createfrommsgarg(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setappid(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, appId: POINTER(Byte), num: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setappid_fromstring(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, appId: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getappid(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, appId: POINTER(POINTER(Byte)), num: POINTER(UIntPtr)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setdefaultlanguage(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, defaultLanguage: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getdefaultlanguage(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, defaultLanguage: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setdevicename(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, deviceName: win32more.Windows.Win32.Foundation.PSTR, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getdevicename(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, deviceName: POINTER(POINTER(SByte)), language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setdeviceid(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, deviceId: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getdeviceid(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, deviceId: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setappname(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, appName: win32more.Windows.Win32.Foundation.PSTR, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getappname(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, appName: POINTER(POINTER(SByte)), language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setmanufacturer(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, manufacturer: win32more.Windows.Win32.Foundation.PSTR, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getmanufacturer(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, manufacturer: POINTER(POINTER(SByte)), language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setmodelnumber(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, modelNumber: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getmodelnumber(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, modelNumber: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setsupportedlanguage(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getsupportedlanguages(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, languageTags: POINTER(POINTER(SByte)), num: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setdescription(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, description: win32more.Windows.Win32.Foundation.PSTR, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getdescription(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, description: POINTER(POINTER(SByte)), language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setdateofmanufacture(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, dateOfManufacture: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getdateofmanufacture(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, dateOfManufacture: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setsoftwareversion(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, softwareVersion: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getsoftwareversion(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, softwareVersion: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getajsoftwareversion(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, ajSoftwareVersion: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_sethardwareversion(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, hardwareVersion: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_gethardwareversion(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, hardwareVersion: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setsupporturl(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, supportUrl: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getsupporturl(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, supportUrl: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_setfield(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getfield(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, name: win32more.Windows.Win32.Foundation.PSTR, value: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg), language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getfields(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, fields: POINTER(POINTER(SByte)), num_fields: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getaboutdata(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, msgArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getannouncedaboutdata(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, msgArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_isfieldrequired(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, fieldName: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_isfieldannounced(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, fieldName: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_isfieldlocalized(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, fieldName: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdata_getfieldsignature(data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata, fieldName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_create() -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_destroy(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_getcontent(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon, data: POINTER(POINTER(Byte)), size: POINTER(UIntPtr)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_setcontent(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon, type: win32more.Windows.Win32.Foundation.PSTR, data: POINTER(Byte), csize: UIntPtr, ownsData: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_geturl(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon, type: POINTER(POINTER(SByte)), url: POINTER(POINTER(SByte))) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_seturl(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon, type: win32more.Windows.Win32.Foundation.PSTR, url: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_clear(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticon_setcontent_frommsgarg(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon, arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getdefaultclaimcapabilities() -> UInt16: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getapplicationstate(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, state: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_setapplicationstate(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, state: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getpublickey(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, publicKey: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_publickey_destroy(publicKey: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getmanifesttemplate(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, manifestTemplateXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_manifesttemplate_destroy(manifestTemplateXml: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_setmanifesttemplatefromxml(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, manifestTemplateXml: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getclaimcapabilities(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, claimCapabilities: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_setclaimcapabilities(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, claimCapabilities: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getclaimcapabilitiesadditionalinfo(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, additionalInfo: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_setclaimcapabilitiesadditionalinfo(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, additionalInfo: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_reset(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_claim(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, caKey: POINTER(SByte), identityCertificateChain: POINTER(SByte), groupId: POINTER(Byte), groupSize: UIntPtr, groupAuthority: POINTER(SByte), manifestsXmls: POINTER(POINTER(SByte)), manifestsCount: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_updateidentity(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, identityCertificateChain: POINTER(SByte), manifestsXmls: POINTER(POINTER(SByte)), manifestsCount: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getidentity(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, identityCertificateChain: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_certificatechain_destroy(certificateChain: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getmanifests(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, manifestArray: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_manifestarray)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_manifestarray_cleanup(manifestArray: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_manifestarray)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_installmanifests(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, manifestsXmls: POINTER(POINTER(SByte)), manifestsCount: UIntPtr, append: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getidentitycertificateid(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, certificateId: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_certificateid)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_certificateid_cleanup(certificateId: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_certificateid)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_updatepolicy(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, policyXml: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getpolicy(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, policyXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getdefaultpolicy(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, policyXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_policy_destroy(policyXml: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_resetpolicy(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_getmembershipsummaries(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, certificateIds: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_certificateidarray)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_certificateidarray_cleanup(certificateIdArray: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_certificateidarray)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_installmembership(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, membershipCertificateChain: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_removemembership(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator, serial: POINTER(Byte), serialLen: UIntPtr, issuerPublicKey: POINTER(SByte), issuerAki: POINTER(Byte), issuerAkiLen: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_startmanagement(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurator_endmanagement(configurator: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_applicationstatelistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_applicationstatelistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_keystorelistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_keystorelistener_with_synchronization_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_with_synchronization_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_keystorelistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_keystorelistener_putkeys(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener, keyStore: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystore, source: win32more.Windows.Win32.Foundation.PSTR, password: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_keystorelistener_getkeys(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener, keyStore: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystore, sink: win32more.Windows.Win32.Foundation.PSTR, sink_sz: POINTER(UIntPtr)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_create(traffic: Byte, isMultipoint: Int32, proximity: Byte, transports: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_destroy(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_get_traffic(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_set_traffic(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, traffic: Byte) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_get_multipoint(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_set_multipoint(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, isMultipoint: Int32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_get_proximity(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_set_proximity(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, proximity: Byte) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_get_transports(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> UInt16: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_set_transports(opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, transports: UInt16) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_iscompatible(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionopts_cmp(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_destroy(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_isbroadcastsignal(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_isglobalbroadcast(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_issessionless(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getflags(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_isexpired(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, tillExpireMS: POINTER(UInt32)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_isunreliable(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_isencrypted(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getauthmechanism(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_gettype(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getargs(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, numArgs: POINTER(UIntPtr), args: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getarg(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, argN: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg: ...
@cfunctype('MSAJApi.dll', variadic=True)
def alljoyn_message_parseargs(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, signature: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getcallserial(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getsignature(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getobjectpath(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getinterface(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getmembername(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getreplyserial(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getsender(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getreceiveendpointname(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getdestination(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getcompressiontoken(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_getsessionid(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_geterrorname(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, errorMessage: win32more.Windows.Win32.Foundation.PSTR, errorMessage_size: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_tostring(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_description(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_gettimestamp(msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_eql(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_message_setendianess(endian: SByte) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistener_requestcredentialsresponse(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, authContext: VoidPtr, accept: Int32, credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistener_verifycredentialsresponse(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, authContext: VoidPtr, accept: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistenerasync_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistenerasync_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistenerasync_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_authlistener_setsharedsecret(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, sharedSecret: POINTER(Byte), sharedSecretSize: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_create() -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_destroy(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_isset(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, creds: UInt16) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setpassword(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, pwd: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setusername(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, userName: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setcertchain(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, certChain: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setprivatekey(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, pk: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setlogonentry(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, logonEntry: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_setexpiration(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, expiration: UInt32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getpassword(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getusername(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getcertchain(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getprivateKey(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getlogonentry(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_getexpiration(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_credentials_clear(cred: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_buslistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_buslistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getannotationscount(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getannotationatindex(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, index: UIntPtr, name: win32more.Windows.Win32.Foundation.PSTR, name_size: POINTER(UIntPtr), value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getannotation(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getargannotationscount(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, argName: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getargannotationatindex(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, argName: win32more.Windows.Win32.Foundation.PSTR, index: UIntPtr, name: win32more.Windows.Win32.Foundation.PSTR, name_size: POINTER(UIntPtr), value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_getargannotation(member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, argName: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_property_getannotationscount(property: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_property_getannotationatindex(property: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property, index: UIntPtr, name: win32more.Windows.Win32.Foundation.PSTR, name_size: POINTER(UIntPtr), value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_property_getannotation(property: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_activate(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getannotationscount(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getannotationatindex(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, index: UIntPtr, name: win32more.Windows.Win32.Foundation.PSTR, name_size: POINTER(UIntPtr), value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmember(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addmember(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, type: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype, name: win32more.Windows.Win32.Foundation.PSTR, inputSig: win32more.Windows.Win32.Foundation.PSTR, outSig: win32more.Windows.Win32.Foundation.PSTR, argNames: win32more.Windows.Win32.Foundation.PSTR, annotation: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addmemberannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmemberannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmembers(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, members: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member), numMembers: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_hasmember(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, inSig: win32more.Windows.Win32.Foundation.PSTR, outSig: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addmethod(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, inputSig: win32more.Windows.Win32.Foundation.PSTR, outSig: win32more.Windows.Win32.Foundation.PSTR, argNames: win32more.Windows.Win32.Foundation.PSTR, annotation: Byte, accessPerms: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmethod(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addsignal(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, sig: win32more.Windows.Win32.Foundation.PSTR, argNames: win32more.Windows.Win32.Foundation.PSTR, annotation: Byte, accessPerms: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getsignal(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getproperty(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, property: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getproperties(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, props: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property), numProps: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addproperty(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, signature: win32more.Windows.Win32.Foundation.PSTR, access: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addpropertyannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, property: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getpropertyannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, property: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, str_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_hasproperty(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_hasproperties(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getname(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_introspect(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, str: win32more.Windows.Win32.Foundation.PSTR, buf: UIntPtr, indent: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_issecure(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getsecuritypolicy(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_securitypolicy: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setdescriptionlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, language: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getdescriptionlanguages(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, languages: POINTER(POINTER(SByte)), size: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getdescriptionlanguages2(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, languages: win32more.Windows.Win32.Foundation.PSTR, languagesSize: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setdescription(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, description: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, description: win32more.Windows.Win32.Foundation.PSTR, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, description: win32more.Windows.Win32.Foundation.PSTR, maxLanguageLength: UIntPtr, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setmemberdescription(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setmemberdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmemberdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, maxLanguageLength: UIntPtr, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setargdescription(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, argName: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setargdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, arg: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getargdescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, arg: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, maxLanguageLength: UIntPtr, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setpropertydescription(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setpropertydescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, name: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getpropertydescriptionforlanguage(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, property: win32more.Windows.Win32.Foundation.PSTR, description: win32more.Windows.Win32.Foundation.PSTR, maxLanguageLength: UIntPtr, languageTag: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_setdescriptiontranslationcallback(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, translationCallback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_translation_callback_ptr) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getdescriptiontranslationcallback(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_translation_callback_ptr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_hasdescription(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_addargannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, argName: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_getmemberargannotation(iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, member: win32more.Windows.Win32.Foundation.PSTR, argName: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, value_size: POINTER(UIntPtr)) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_eql(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_member_eql(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_interfacedescription_property_eql(one: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property, other: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_property) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_create(path: win32more.Windows.Win32.Foundation.PSTR, isPlaceholder: Int32, callbacks_in: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_callbacks), context_in: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_destroy(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_getpath(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_emitpropertychanged(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, ifcName: win32more.Windows.Win32.Foundation.PSTR, propName: win32more.Windows.Win32.Foundation.PSTR, val: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, id: UInt32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_emitpropertieschanged(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, ifcName: win32more.Windows.Win32.Foundation.PSTR, propNames: POINTER(POINTER(SByte)), numProps: UIntPtr, id: UInt32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_getname(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, buffer: win32more.Windows.Win32.Foundation.PSTR, bufferSz: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_addinterface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_addmethodhandler(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_methodhandler_ptr, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_addmethodhandlers(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, entries: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_methodentry), numEntries: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_methodreply_args(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_methodreply_err(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, error: win32more.Windows.Win32.Foundation.PSTR, errorMessage: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_methodreply_status(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, status: win32more.Windows.Win32.Devices.AllJoyn.QStatus) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_getbusattachment(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_signal(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, destination: win32more.Windows.Win32.Foundation.PSTR, sessionId: UInt32, signal: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, timeToLive: UInt16, flags: Byte, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_cancelsessionlessmessage_serial(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, serialNumber: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_cancelsessionlessmessage(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_issecure(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_getannouncedinterfacenames(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, interfaces: POINTER(POINTER(SByte)), numInterfaces: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_setannounceflag(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription, isAnnounced: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_about_announceflag) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busobject_addinterface_announced(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, service: win32more.Windows.Win32.Foundation.PSTR, path: win32more.Windows.Win32.Foundation.PSTR, sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_create_secure(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, service: win32more.Windows.Win32.Foundation.PSTR, path: win32more.Windows.Win32.Foundation.PSTR, sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_destroy(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_addinterface(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_addinterface_by_name(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getchildren(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, children: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject), numChildren: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getchild(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_addchild(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, child: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_removechild(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_introspectremoteobject(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_introspectremoteobjectasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_introspectcb_ptr, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getproperty(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, property: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getpropertyasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, property: win32more.Windows.Win32.Foundation.PSTR, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_getpropertycb_ptr, timeout: UInt32, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getallproperties(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, values: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getallpropertiesasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_getallpropertiescb_ptr, timeout: UInt32, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_setproperty(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, property: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_registerpropertieschangedlistener(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, properties: POINTER(POINTER(SByte)), numProperties: UIntPtr, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_propertieschanged_ptr, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_unregisterpropertieschangedlistener(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_propertieschanged_ptr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_setpropertyasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR, property: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_listener_setpropertycb_ptr, timeout: UInt32, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcall(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, ifaceName: win32more.Windows.Win32.Foundation.PSTR, methodName: win32more.Windows.Win32.Foundation.PSTR, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, replyMsg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, timeout: UInt32, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcall_member(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, method: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, replyMsg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, timeout: UInt32, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcall_noreply(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, ifaceName: win32more.Windows.Win32.Foundation.PSTR, methodName: win32more.Windows.Win32.Foundation.PSTR, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcall_member_noreply(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, method: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcallasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, ifaceName: win32more.Windows.Win32.Foundation.PSTR, methodName: win32more.Windows.Win32.Foundation.PSTR, replyFunc: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_replyhandler_ptr, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, context: VoidPtr, timeout: UInt32, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_methodcallasync_member(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, method: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, replyFunc: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_replyhandler_ptr, args: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, numArgs: UIntPtr, context: VoidPtr, timeout: UInt32, flags: Byte) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_parsexml(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, xml: win32more.Windows.Win32.Foundation.PSTR, identifier: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_secureconnection(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, forceAuth: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_secureconnectionasync(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, forceAuth: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getinterface(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getinterfaces(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, ifaces: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription), numIfaces: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getpath(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getservicename(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getuniquename(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_getsessionid(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_implementsinterface(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, iface: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_copy(source: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_isvalid(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_issecure(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_enablepropertycaching(proxyObj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurationlistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_permissionconfigurationlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionlistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionportlistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_sessionportlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutlistener_create(callback: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutlistener_callback), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_create(applicationName: win32more.Windows.Win32.Foundation.PSTR, allowRemoteMessages: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_create_concurrency(applicationName: win32more.Windows.Win32.Foundation.PSTR, allowRemoteMessages: Int32, concurrency: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_destroy(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_start(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_stop(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_join(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getconcurrency(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getconnectspec(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_enableconcurrentcallbacks(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_createinterface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, iface: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_createinterface_secure(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, iface: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription), secPolicy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_securitypolicy) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_connect(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, connectSpec: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registerbuslistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisterbuslistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_findadvertisedname(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, namePrefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_findadvertisednamebytransport(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, namePrefix: win32more.Windows.Win32.Foundation.PSTR, transports: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_cancelfindadvertisedname(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, namePrefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_cancelfindadvertisednamebytransport(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, namePrefix: win32more.Windows.Win32.Foundation.PSTR, transports: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_advertisename(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, transports: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_canceladvertisename(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, transports: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getinterface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_joinsession(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionHost: win32more.Windows.Win32.Foundation.PSTR, sessionPort: UInt16, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener, sessionId: POINTER(UInt32), opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_joinsessionasync(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionHost: win32more.Windows.Win32.Foundation.PSTR, sessionPort: UInt16, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener, opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment_joinsessioncb_ptr, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registerbusobject(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registerbusobject_secure(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisterbusobject(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, object: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_requestname(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, requestedName: win32more.Windows.Win32.Foundation.PSTR, flags: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_releasename(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_bindsessionport(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionPort: POINTER(UInt16), opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unbindsessionport(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionPort: UInt16) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_enablepeersecurity(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, authMechanisms: win32more.Windows.Win32.Foundation.PSTR, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, keyStoreFileName: win32more.Windows.Win32.Foundation.PSTR, isShared: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_enablepeersecuritywithpermissionconfigurationlistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, authMechanisms: win32more.Windows.Win32.Foundation.PSTR, authListener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, keyStoreFileName: win32more.Windows.Win32.Foundation.PSTR, isShared: Int32, permissionConfigurationListener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_ispeersecurityenabled(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_createinterfacesfromxml(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, xml: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getinterfaces(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, ifaces: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription), numIfaces: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_deleteinterface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_isstarted(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_isstopping(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_isconnected(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Int32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_disconnect(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, unused: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getdbusproxyobj(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getalljoynproxyobj(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getalljoyndebugobj(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getuniquename(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getglobalguidstring(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registersignalhandler(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, signal_handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_signalhandler_ptr, member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, srcPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registersignalhandlerwithrule(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, signal_handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_signalhandler_ptr, member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, matchRule: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregistersignalhandler(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, signal_handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_signalhandler_ptr, member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, srcPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregistersignalhandlerwithrule(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, signal_handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_signalhandler_ptr, member: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member, matchRule: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisterallhandlers(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registerkeystorelistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_reloadkeystore(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_clearkeystore(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_clearkeys(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, guid: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_setkeyexpiration(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, guid: win32more.Windows.Win32.Foundation.PSTR, timeout: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getkeyexpiration(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, guid: win32more.Windows.Win32.Foundation.PSTR, timeout: POINTER(UInt32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_addlogonentry(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, authMechanism: win32more.Windows.Win32.Foundation.PSTR, userName: win32more.Windows.Win32.Foundation.PSTR, password: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_addmatch(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, rule: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_removematch(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, rule: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_setsessionlistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionId: UInt32, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_leavesession(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_secureconnection(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, forceAuth: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_secureconnectionasync(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, forceAuth: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_removesessionmember(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionId: UInt32, memberName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_setlinktimeout(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionid: UInt32, linkTimeout: POINTER(UInt32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_setlinktimeoutasync(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, sessionid: UInt32, linkTimeout: UInt32, callback: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment_setlinktimeoutcb_ptr, context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_namehasowner(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, hasOwner: POINTER(Int32)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getpeerguid(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, guid: win32more.Windows.Win32.Foundation.PSTR, guidSz: POINTER(UIntPtr)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_setdaemondebug(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, module: win32more.Windows.Win32.Foundation.PSTR, level: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_gettimestamp() -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_ping(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, name: win32more.Windows.Win32.Foundation.PSTR, timeout: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registeraboutlistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, aboutListener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisteraboutlistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, aboutListener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisterallaboutlisteners(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_whoimplements_interfaces(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, implementsInterfaces: POINTER(POINTER(SByte)), numberInterfaces: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_whoimplements_interface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, implementsInterface: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_cancelwhoimplements_interfaces(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, implementsInterfaces: POINTER(POINTER(SByte)), numberInterfaces: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_cancelwhoimplements_interface(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, implementsInterface: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_getpermissionconfigurator(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurator: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_registerapplicationstatelistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_unregisterapplicationstatelistener(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_busattachment_deletedefaultkeystore(applicationName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonobj_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonobj: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonobj_destroy(icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonobj) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonproxy_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, busName: win32more.Windows.Win32.Foundation.PSTR, sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonproxy: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonproxy_destroy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonproxy) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonproxy_geticon(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonproxy, icon: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticon) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_abouticonproxy_getversion(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_abouticonproxy, version: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdatalistener_create(callbacks: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener_callbacks), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutdatalistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobj_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, isAnnounced: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_about_announceflag) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobj: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobj_destroy(obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobj) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobj_announce(obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobj, sessionPort: UInt16, aboutData: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdata) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobj_announce_using_datalistener(obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobj, sessionPort: UInt16, aboutListener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobj_unannounce(obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobj) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_create() -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_create_full(arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_createfrommsgarg(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, arg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_destroy(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_getpaths(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, paths: POINTER(POINTER(SByte)), numPaths: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_getinterfaces(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, path: win32more.Windows.Win32.Foundation.PSTR, interfaces: POINTER(POINTER(SByte)), numInterfaces: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_getinterfacepaths(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, interfaceName: win32more.Windows.Win32.Foundation.PSTR, paths: POINTER(POINTER(SByte)), numPaths: UIntPtr) -> UIntPtr: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_clear(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_haspath(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, path: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_hasinterface(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, interfaceName: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_hasinterfaceatpath(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, path: win32more.Windows.Win32.Foundation.PSTR, interfaceName: win32more.Windows.Win32.Foundation.PSTR) -> Byte: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutobjectdescription_getmsgarg(description: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutobjectdescription, msgArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutproxy_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, busName: win32more.Windows.Win32.Foundation.PSTR, sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutproxy: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutproxy_destroy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutproxy) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutproxy_getobjectdescription(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutproxy, objectDesc: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutproxy_getaboutdata(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutproxy, language: win32more.Windows.Win32.Foundation.PSTR, data: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_aboutproxy_getversion(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutproxy, version: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_pinglistener_create(callback: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_pinglistener_callback), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_pinglistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_pinglistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_pinglistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_destroy(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_pause(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_resume(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_addpinggroup(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger, group: win32more.Windows.Win32.Foundation.PSTR, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_pinglistener, pinginterval: UInt32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_removepinggroup(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger, group: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_setpinginterval(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger, group: win32more.Windows.Win32.Foundation.PSTR, pinginterval: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_adddestination(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger, group: win32more.Windows.Win32.Foundation.PSTR, destination: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_autopinger_removedestination(autopinger: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger, group: win32more.Windows.Win32.Foundation.PSTR, destination: win32more.Windows.Win32.Foundation.PSTR, removeall: Int32) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_getversion() -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_getbuildinfo() -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('MSAJApi.dll')
def alljoyn_getnumericversion() -> UInt32: ...
@winfunctype('MSAJApi.dll')
def alljoyn_init() -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_shutdown() -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_routerinit() -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_routerinitwithconfig(configXml: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_routershutdown() -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_ref_create(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_ref_get(ref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_ref_incref(ref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_proxybusobject_ref_decref(ref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observerlistener_create(callback: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observerlistener_callback), context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observerlistener: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observerlistener_destroy(listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observerlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, mandatoryInterfaces: POINTER(POINTER(SByte)), numMandatoryInterfaces: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_destroy(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_registerlistener(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observerlistener, triggerOnExisting: Int32) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_unregisterlistener(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observerlistener) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_unregisteralllisteners(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_get(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer, uniqueBusName: win32more.Windows.Win32.Foundation.PSTR, objectPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_getfirst(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref: ...
@winfunctype('MSAJApi.dll')
def alljoyn_observer_getnext(observer: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer, proxyref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref: ...
@winfunctype('MSAJApi.dll')
def alljoyn_passwordmanager_setcredentials(authMechanism: win32more.Windows.Win32.Foundation.PSTR, password: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getpermissionmanagementsessionport() -> UInt16: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_create(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment, appBusName: POINTER(SByte), sessionId: UInt32) -> win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_destroy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_claim(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, caKey: POINTER(SByte), identityCertificateChain: POINTER(SByte), groupId: POINTER(Byte), groupSize: UIntPtr, groupAuthority: POINTER(SByte), manifestsXmls: POINTER(POINTER(SByte)), manifestsCount: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getmanifesttemplate(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, manifestTemplateXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_manifesttemplate_destroy(manifestTemplateXml: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getapplicationstate(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, applicationState: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getclaimcapabilities(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, capabilities: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getclaimcapabilitiesadditionalinfo(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, additionalInfo: POINTER(UInt16)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getpolicy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, policyXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_getdefaultpolicy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, policyXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_policy_destroy(policyXml: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_updatepolicy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, policyXml: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_updateidentity(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, identityCertificateChain: POINTER(SByte), manifestsXmls: POINTER(POINTER(SByte)), manifestsCount: UIntPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_installmembership(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, membershipCertificateChain: POINTER(SByte)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_reset(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_resetpolicy(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_startmanagement(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_endmanagement(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_geteccpublickey(proxy: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_securityapplicationproxy, eccPublicKey: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_eccpublickey_destroy(eccPublicKey: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_signmanifest(unsignedManifestXml: POINTER(SByte), identityCertificatePem: POINTER(SByte), signingPrivateKeyPem: POINTER(SByte), signedManifestXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_manifest_destroy(signedManifestXml: POINTER(SByte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_computemanifestdigest(unsignedManifestXml: POINTER(SByte), identityCertificatePem: POINTER(SByte), digest: POINTER(POINTER(Byte)), digestSize: POINTER(UIntPtr)) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_digest_destroy(digest: POINTER(Byte)) -> Void: ...
@winfunctype('MSAJApi.dll')
def alljoyn_securityapplicationproxy_setmanifestsignature(unsignedManifestXml: POINTER(SByte), identityCertificatePem: POINTER(SByte), signature: POINTER(Byte), signatureSize: UIntPtr, signedManifestXml: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
QStatus = Int32
ER_OK: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 0
ER_FAIL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 1
ER_UTF_CONVERSION_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 2
ER_BUFFER_TOO_SMALL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 3
ER_OS_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4
ER_OUT_OF_MEMORY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 5
ER_SOCKET_BIND_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 6
ER_INIT_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 7
ER_WOULDBLOCK: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8
ER_NOT_IMPLEMENTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 9
ER_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 10
ER_SOCK_OTHER_END_CLOSED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 11
ER_BAD_ARG_1: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 12
ER_BAD_ARG_2: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 13
ER_BAD_ARG_3: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 14
ER_BAD_ARG_4: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 15
ER_BAD_ARG_5: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 16
ER_BAD_ARG_6: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 17
ER_BAD_ARG_7: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 18
ER_BAD_ARG_8: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 19
ER_INVALID_ADDRESS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 20
ER_INVALID_DATA: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 21
ER_READ_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 22
ER_WRITE_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 23
ER_OPEN_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 24
ER_PARSE_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 25
ER_END_OF_DATA: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 26
ER_CONN_REFUSED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 27
ER_BAD_ARG_COUNT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 28
ER_WARNING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 29
ER_EOF: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 30
ER_DEADLOCK: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 31
ER_COMMON_ERRORS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4096
ER_STOPPING_THREAD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4097
ER_ALERTED_THREAD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4098
ER_XML_MALFORMED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4099
ER_AUTH_FAIL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4100
ER_AUTH_USER_REJECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4101
ER_NO_SUCH_ALARM: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4102
ER_TIMER_FALLBEHIND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4103
ER_SSL_ERRORS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4104
ER_SSL_INIT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4105
ER_SSL_CONNECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4106
ER_SSL_VERIFY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4107
ER_EXTERNAL_THREAD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4108
ER_CRYPTO_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4109
ER_CRYPTO_TRUNCATED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4110
ER_CRYPTO_KEY_UNAVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4111
ER_BAD_HOSTNAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4112
ER_CRYPTO_KEY_UNUSABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4113
ER_EMPTY_KEY_BLOB: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4114
ER_CORRUPT_KEYBLOB: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4115
ER_INVALID_KEY_ENCODING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4116
ER_DEAD_THREAD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4117
ER_THREAD_RUNNING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4118
ER_THREAD_STOPPING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4119
ER_BAD_STRING_ENCODING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4120
ER_CRYPTO_INSUFFICIENT_SECURITY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4121
ER_CRYPTO_ILLEGAL_PARAMETERS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4122
ER_CRYPTO_HASH_UNINITIALIZED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4123
ER_THREAD_NO_WAIT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4124
ER_TIMER_EXITING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4125
ER_INVALID_GUID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4126
ER_THREADPOOL_EXHAUSTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4127
ER_THREADPOOL_STOPPING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4128
ER_INVALID_STREAM: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4129
ER_TIMER_FULL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4130
ER_IODISPATCH_STOPPING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4131
ER_SLAP_INVALID_PACKET_LEN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4132
ER_SLAP_HDR_CHECKSUM_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4133
ER_SLAP_INVALID_PACKET_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4134
ER_SLAP_LEN_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4135
ER_SLAP_PACKET_TYPE_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4136
ER_SLAP_CRC_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4137
ER_SLAP_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4138
ER_SLAP_OTHER_END_CLOSED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4139
ER_TIMER_NOT_ALLOWED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4140
ER_NOT_CONN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 4141
ER_XML_CONVERTER_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8192
ER_XML_INVALID_RULES_COUNT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8193
ER_XML_INTERFACE_MEMBERS_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8194
ER_XML_INVALID_MEMBER_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8195
ER_XML_INVALID_MEMBER_ACTION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8196
ER_XML_MEMBER_DENY_ACTION_WITH_OTHER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8197
ER_XML_INVALID_ANNOTATIONS_COUNT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8198
ER_XML_INVALID_ELEMENT_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8199
ER_XML_INVALID_ATTRIBUTE_VALUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8200
ER_XML_INVALID_SECURITY_LEVEL_ANNOTATION_VALUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8201
ER_XML_INVALID_ELEMENT_CHILDREN_COUNT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8202
ER_XML_INVALID_POLICY_VERSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8203
ER_XML_INVALID_POLICY_SERIAL_NUMBER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8204
ER_XML_INVALID_ACL_PEER_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8205
ER_XML_INVALID_ACL_PEER_CHILDREN_COUNT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8206
ER_XML_ACL_ALL_TYPE_PEER_WITH_OTHERS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8207
ER_XML_INVALID_ACL_PEER_PUBLIC_KEY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8208
ER_XML_ACL_PEER_NOT_UNIQUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8209
ER_XML_ACL_PEER_PUBLIC_KEY_SET: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8210
ER_XML_ACLS_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8211
ER_XML_ACL_PEERS_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8212
ER_XML_INVALID_OBJECT_PATH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8213
ER_XML_INVALID_INTERFACE_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8214
ER_XML_INVALID_MEMBER_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8215
ER_XML_INVALID_MANIFEST_VERSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8216
ER_XML_INVALID_OID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8217
ER_XML_INVALID_BASE64: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8218
ER_XML_INTERFACE_NAME_NOT_UNIQUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8219
ER_XML_MEMBER_NAME_NOT_UNIQUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8220
ER_XML_OBJECT_PATH_NOT_UNIQUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8221
ER_XML_ANNOTATION_NOT_UNIQUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 8222
ER_NONE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 65535
ER_BUS_ERRORS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36864
ER_BUS_READ_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36865
ER_BUS_WRITE_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36866
ER_BUS_BAD_VALUE_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36867
ER_BUS_BAD_HEADER_FIELD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36868
ER_BUS_BAD_SIGNATURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36869
ER_BUS_BAD_OBJ_PATH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36870
ER_BUS_BAD_MEMBER_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36871
ER_BUS_BAD_INTERFACE_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36872
ER_BUS_BAD_ERROR_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36873
ER_BUS_BAD_BUS_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36874
ER_BUS_NAME_TOO_LONG: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36875
ER_BUS_BAD_LENGTH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36876
ER_BUS_BAD_VALUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36877
ER_BUS_BAD_HDR_FLAGS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36878
ER_BUS_BAD_BODY_LEN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36879
ER_BUS_BAD_HEADER_LEN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36880
ER_BUS_UNKNOWN_SERIAL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36881
ER_BUS_UNKNOWN_PATH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36882
ER_BUS_UNKNOWN_INTERFACE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36883
ER_BUS_ESTABLISH_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36884
ER_BUS_UNEXPECTED_SIGNATURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36885
ER_BUS_INTERFACE_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36886
ER_BUS_PATH_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36887
ER_BUS_MEMBER_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36888
ER_BUS_REPLY_SERIAL_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36889
ER_BUS_ERROR_NAME_MISSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36890
ER_BUS_INTERFACE_NO_SUCH_MEMBER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36891
ER_BUS_NO_SUCH_OBJECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36892
ER_BUS_OBJECT_NO_SUCH_MEMBER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36893
ER_BUS_OBJECT_NO_SUCH_INTERFACE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36894
ER_BUS_NO_SUCH_INTERFACE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36895
ER_BUS_MEMBER_NO_SUCH_SIGNATURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36896
ER_BUS_NOT_NUL_TERMINATED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36897
ER_BUS_NO_SUCH_PROPERTY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36898
ER_BUS_SET_WRONG_SIGNATURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36899
ER_BUS_PROPERTY_VALUE_NOT_SET: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36900
ER_BUS_PROPERTY_ACCESS_DENIED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36901
ER_BUS_NO_TRANSPORTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36902
ER_BUS_BAD_TRANSPORT_ARGS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36903
ER_BUS_NO_ROUTE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36904
ER_BUS_NO_ENDPOINT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36905
ER_BUS_BAD_SEND_PARAMETER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36906
ER_BUS_UNMATCHED_REPLY_SERIAL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36907
ER_BUS_BAD_SENDER_ID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36908
ER_BUS_TRANSPORT_NOT_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36909
ER_BUS_EMPTY_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36910
ER_BUS_NOT_OWNER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36911
ER_BUS_SET_PROPERTY_REJECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36912
ER_BUS_CONNECT_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36913
ER_BUS_REPLY_IS_ERROR_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36914
ER_BUS_NOT_AUTHENTICATING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36915
ER_BUS_NO_LISTENER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36916
ER_BUS_NOT_ALLOWED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36918
ER_BUS_WRITE_QUEUE_FULL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36919
ER_BUS_ENDPOINT_CLOSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36920
ER_BUS_INTERFACE_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36921
ER_BUS_MEMBER_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36922
ER_BUS_PROPERTY_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36923
ER_BUS_IFACE_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36924
ER_BUS_ERROR_RESPONSE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36925
ER_BUS_BAD_XML: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36926
ER_BUS_BAD_CHILD_PATH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36927
ER_BUS_OBJ_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36928
ER_BUS_OBJ_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36929
ER_BUS_CANNOT_EXPAND_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36930
ER_BUS_NOT_COMPRESSED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36931
ER_BUS_ALREADY_CONNECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36932
ER_BUS_NOT_CONNECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36933
ER_BUS_ALREADY_LISTENING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36934
ER_BUS_KEY_UNAVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36935
ER_BUS_TRUNCATED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36936
ER_BUS_KEY_STORE_NOT_LOADED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36937
ER_BUS_NO_AUTHENTICATION_MECHANISM: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36938
ER_BUS_BUS_ALREADY_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36939
ER_BUS_BUS_NOT_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36940
ER_BUS_KEYBLOB_OP_INVALID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36941
ER_BUS_INVALID_HEADER_CHECKSUM: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36942
ER_BUS_MESSAGE_NOT_ENCRYPTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36943
ER_BUS_INVALID_HEADER_SERIAL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36944
ER_BUS_TIME_TO_LIVE_EXPIRED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36945
ER_BUS_HDR_EXPANSION_INVALID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36946
ER_BUS_MISSING_COMPRESSION_TOKEN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36947
ER_BUS_NO_PEER_GUID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36948
ER_BUS_MESSAGE_DECRYPTION_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36949
ER_BUS_SECURITY_FATAL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36950
ER_BUS_KEY_EXPIRED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36951
ER_BUS_CORRUPT_KEYSTORE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36952
ER_BUS_NO_CALL_FOR_REPLY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36953
ER_BUS_NOT_A_COMPLETE_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36954
ER_BUS_POLICY_VIOLATION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36955
ER_BUS_NO_SUCH_SERVICE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36956
ER_BUS_TRANSPORT_NOT_AVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36957
ER_BUS_INVALID_AUTH_MECHANISM: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36958
ER_BUS_KEYSTORE_VERSION_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36959
ER_BUS_BLOCKING_CALL_NOT_ALLOWED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36960
ER_BUS_SIGNATURE_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36961
ER_BUS_STOPPING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36962
ER_BUS_METHOD_CALL_ABORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36963
ER_BUS_CANNOT_ADD_INTERFACE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36964
ER_BUS_CANNOT_ADD_HANDLER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36965
ER_BUS_KEYSTORE_NOT_LOADED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36966
ER_BUS_NO_SUCH_HANDLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36971
ER_BUS_HANDLES_NOT_ENABLED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36972
ER_BUS_HANDLES_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36973
ER_BUS_NO_SESSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36975
ER_BUS_ELEMENT_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36976
ER_BUS_NOT_A_DICTIONARY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36977
ER_BUS_WAIT_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36978
ER_BUS_BAD_SESSION_OPTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36980
ER_BUS_CONNECTION_REJECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36981
ER_DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36982
ER_DBUS_REQUEST_NAME_REPLY_IN_QUEUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36983
ER_DBUS_REQUEST_NAME_REPLY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36984
ER_DBUS_REQUEST_NAME_REPLY_ALREADY_OWNER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36985
ER_DBUS_RELEASE_NAME_REPLY_RELEASED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36986
ER_DBUS_RELEASE_NAME_REPLY_NON_EXISTENT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36987
ER_DBUS_RELEASE_NAME_REPLY_NOT_OWNER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36988
ER_DBUS_START_REPLY_ALREADY_RUNNING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36990
ER_ALLJOYN_BINDSESSIONPORT_REPLY_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36992
ER_ALLJOYN_BINDSESSIONPORT_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36993
ER_ALLJOYN_JOINSESSION_REPLY_NO_SESSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36995
ER_ALLJOYN_JOINSESSION_REPLY_UNREACHABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36996
ER_ALLJOYN_JOINSESSION_REPLY_CONNECT_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36997
ER_ALLJOYN_JOINSESSION_REPLY_REJECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36998
ER_ALLJOYN_JOINSESSION_REPLY_BAD_SESSION_OPTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 36999
ER_ALLJOYN_JOINSESSION_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37000
ER_ALLJOYN_LEAVESESSION_REPLY_NO_SESSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37002
ER_ALLJOYN_LEAVESESSION_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37003
ER_ALLJOYN_ADVERTISENAME_REPLY_TRANSPORT_NOT_AVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37004
ER_ALLJOYN_ADVERTISENAME_REPLY_ALREADY_ADVERTISING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37005
ER_ALLJOYN_ADVERTISENAME_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37006
ER_ALLJOYN_CANCELADVERTISENAME_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37008
ER_ALLJOYN_FINDADVERTISEDNAME_REPLY_TRANSPORT_NOT_AVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37009
ER_ALLJOYN_FINDADVERTISEDNAME_REPLY_ALREADY_DISCOVERING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37010
ER_ALLJOYN_FINDADVERTISEDNAME_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37011
ER_ALLJOYN_CANCELFINDADVERTISEDNAME_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37013
ER_BUS_UNEXPECTED_DISPOSITION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37014
ER_BUS_INTERFACE_ACTIVATED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37015
ER_ALLJOYN_UNBINDSESSIONPORT_REPLY_BAD_PORT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37016
ER_ALLJOYN_UNBINDSESSIONPORT_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37017
ER_ALLJOYN_BINDSESSIONPORT_REPLY_INVALID_OPTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37018
ER_ALLJOYN_JOINSESSION_REPLY_ALREADY_JOINED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37019
ER_BUS_SELF_CONNECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37020
ER_BUS_SECURITY_NOT_ENABLED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37021
ER_BUS_LISTENER_ALREADY_SET: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37022
ER_BUS_PEER_AUTH_VERSION_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37023
ER_ALLJOYN_SETLINKTIMEOUT_REPLY_NOT_SUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37024
ER_ALLJOYN_SETLINKTIMEOUT_REPLY_NO_DEST_SUPPORT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37025
ER_ALLJOYN_SETLINKTIMEOUT_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37026
ER_ALLJOYN_ACCESS_PERMISSION_WARNING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37027
ER_ALLJOYN_ACCESS_PERMISSION_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37028
ER_BUS_DESTINATION_NOT_AUTHENTICATED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37029
ER_BUS_ENDPOINT_REDIRECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37030
ER_BUS_AUTHENTICATION_PENDING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37031
ER_BUS_NOT_AUTHORIZED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37032
ER_PACKET_BUS_NO_SUCH_CHANNEL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37033
ER_PACKET_BAD_FORMAT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37034
ER_PACKET_CONNECT_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37035
ER_PACKET_CHANNEL_FAIL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37036
ER_PACKET_TOO_LARGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37037
ER_PACKET_BAD_PARAMETER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37038
ER_PACKET_BAD_CRC: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37039
ER_RENDEZVOUS_SERVER_DEACTIVATED_USER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37067
ER_RENDEZVOUS_SERVER_UNKNOWN_USER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37068
ER_UNABLE_TO_CONNECT_TO_RENDEZVOUS_SERVER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37069
ER_NOT_CONNECTED_TO_RENDEZVOUS_SERVER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37070
ER_UNABLE_TO_SEND_MESSAGE_TO_RENDEZVOUS_SERVER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37071
ER_INVALID_RENDEZVOUS_SERVER_INTERFACE_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37072
ER_INVALID_PERSISTENT_CONNECTION_MESSAGE_RESPONSE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37073
ER_INVALID_ON_DEMAND_CONNECTION_MESSAGE_RESPONSE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37074
ER_INVALID_HTTP_METHOD_USED_FOR_RENDEZVOUS_SERVER_INTERFACE_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37075
ER_RENDEZVOUS_SERVER_ERR500_INTERNAL_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37076
ER_RENDEZVOUS_SERVER_ERR503_STATUS_UNAVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37077
ER_RENDEZVOUS_SERVER_ERR401_UNAUTHORIZED_REQUEST: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37078
ER_RENDEZVOUS_SERVER_UNRECOVERABLE_ERROR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37079
ER_RENDEZVOUS_SERVER_ROOT_CERTIFICATE_UNINITIALIZED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37080
ER_BUS_NO_SUCH_ANNOTATION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37081
ER_BUS_ANNOTATION_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37082
ER_SOCK_CLOSING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37083
ER_NO_SUCH_DEVICE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37084
ER_P2P: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37085
ER_P2P_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37086
ER_P2P_NOT_CONNECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37087
ER_BAD_TRANSPORT_MASK: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37088
ER_PROXIMITY_CONNECTION_ESTABLISH_FAIL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37089
ER_PROXIMITY_NO_PEERS_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37090
ER_BUS_OBJECT_NOT_REGISTERED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37091
ER_P2P_DISABLED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37092
ER_P2P_BUSY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37093
ER_BUS_INCOMPATIBLE_DAEMON: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37094
ER_P2P_NO_GO: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37095
ER_P2P_NO_STA: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37096
ER_P2P_FORBIDDEN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37097
ER_ALLJOYN_ONAPPSUSPEND_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37098
ER_ALLJOYN_ONAPPSUSPEND_REPLY_UNSUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37099
ER_ALLJOYN_ONAPPRESUME_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37100
ER_ALLJOYN_ONAPPRESUME_REPLY_UNSUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37101
ER_BUS_NO_SUCH_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37102
ER_ALLJOYN_REMOVESESSIONMEMBER_REPLY_NO_SESSION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37103
ER_ALLJOYN_REMOVESESSIONMEMBER_NOT_BINDER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37104
ER_ALLJOYN_REMOVESESSIONMEMBER_NOT_MULTIPOINT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37105
ER_ALLJOYN_REMOVESESSIONMEMBER_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37106
ER_ALLJOYN_REMOVESESSIONMEMBER_INCOMPATIBLE_REMOTE_DAEMON: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37107
ER_ALLJOYN_REMOVESESSIONMEMBER_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37108
ER_BUS_REMOVED_BY_BINDER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37109
ER_BUS_MATCH_RULE_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37110
ER_ALLJOYN_PING_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37111
ER_ALLJOYN_PING_REPLY_UNREACHABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37112
ER_UDP_MSG_TOO_LONG: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37113
ER_UDP_DEMUX_NO_ENDPOINT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37114
ER_UDP_NO_NETWORK: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37115
ER_UDP_UNEXPECTED_LENGTH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37116
ER_UDP_UNEXPECTED_FLOW: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37117
ER_UDP_DISCONNECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37118
ER_UDP_NOT_IMPLEMENTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37119
ER_UDP_NO_LISTENER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37120
ER_UDP_STOPPING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37121
ER_ARDP_BACKPRESSURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37122
ER_UDP_BACKPRESSURE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37123
ER_ARDP_INVALID_STATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37124
ER_ARDP_TTL_EXPIRED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37125
ER_ARDP_PERSIST_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37126
ER_ARDP_PROBE_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37127
ER_ARDP_REMOTE_CONNECTION_RESET: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37128
ER_UDP_BUSHELLO: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37129
ER_UDP_MESSAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37130
ER_UDP_INVALID: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37131
ER_UDP_UNSUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37132
ER_UDP_ENDPOINT_STALLED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37133
ER_ARDP_INVALID_RESPONSE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37134
ER_ARDP_INVALID_CONNECTION: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37135
ER_UDP_LOCAL_DISCONNECT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37136
ER_UDP_EARLY_EXIT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37137
ER_UDP_LOCAL_DISCONNECT_FAIL: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37138
ER_ARDP_DISCONNECTING: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37139
ER_ALLJOYN_PING_REPLY_INCOMPATIBLE_REMOTE_ROUTING_NODE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37140
ER_ALLJOYN_PING_REPLY_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37141
ER_ALLJOYN_PING_REPLY_UNKNOWN_NAME: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37142
ER_ALLJOYN_PING_REPLY_FAILED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37143
ER_TCP_MAX_UNTRUSTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37144
ER_ALLJOYN_PING_REPLY_IN_PROGRESS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37145
ER_LANGUAGE_NOT_SUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37146
ER_ABOUT_FIELD_ALREADY_SPECIFIED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37147
ER_UDP_NOT_DISCONNECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37148
ER_UDP_ENDPOINT_NOT_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37149
ER_UDP_ENDPOINT_REMOVED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37150
ER_ARDP_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37151
ER_CONNECTION_LIMIT_EXCEEDED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37152
ER_ARDP_WRITE_BLOCKED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37153
ER_PERMISSION_DENIED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37154
ER_ABOUT_DEFAULT_LANGUAGE_NOT_SPECIFIED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37155
ER_ABOUT_SESSIONPORT_NOT_BOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37156
ER_ABOUT_ABOUTDATA_MISSING_REQUIRED_FIELD: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37157
ER_ABOUT_INVALID_ABOUTDATA_LISTENER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37158
ER_BUS_PING_GROUP_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37159
ER_BUS_REMOVED_BY_BINDER_SELF: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37160
ER_INVALID_CONFIG: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37161
ER_ABOUT_INVALID_ABOUTDATA_FIELD_VALUE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37162
ER_ABOUT_INVALID_ABOUTDATA_FIELD_APPID_SIZE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37163
ER_BUS_TRANSPORT_ACCESS_DENIED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37164
ER_INVALID_CERTIFICATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37165
ER_CERTIFICATE_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37166
ER_DUPLICATE_CERTIFICATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37167
ER_UNKNOWN_CERTIFICATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37168
ER_MISSING_DIGEST_IN_CERTIFICATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37169
ER_DIGEST_MISMATCH: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37170
ER_DUPLICATE_KEY: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37171
ER_NO_COMMON_TRUST: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37172
ER_MANIFEST_NOT_FOUND: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37173
ER_INVALID_CERT_CHAIN: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37174
ER_NO_TRUST_ANCHOR: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37175
ER_INVALID_APPLICATION_STATE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37176
ER_FEATURE_NOT_AVAILABLE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37177
ER_KEY_STORE_ALREADY_INITIALIZED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37178
ER_KEY_STORE_ID_NOT_YET_SET: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37179
ER_POLICY_NOT_NEWER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37180
ER_MANIFEST_REJECTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37181
ER_INVALID_CERTIFICATE_USAGE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37182
ER_INVALID_SIGNAL_EMISSION_TYPE: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37183
ER_APPLICATION_STATE_LISTENER_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37184
ER_APPLICATION_STATE_LISTENER_NO_SUCH_LISTENER: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37185
ER_MANAGEMENT_ALREADY_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37186
ER_MANAGEMENT_NOT_STARTED: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37187
ER_BUS_DESCRIPTION_ALREADY_EXISTS: win32more.Windows.Win32.Devices.AllJoyn.QStatus = 37188
@winfunctype_pointer
def alljoyn_about_announced_ptr(context: VoidPtr, busName: win32more.Windows.Win32.Foundation.PSTR, version: UInt16, port: UInt16, objectDescriptionArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, aboutDataArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
alljoyn_about_announceflag = Int32
UNANNOUNCED: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_about_announceflag = 0
ANNOUNCED: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_about_announceflag = 1
alljoyn_aboutdata = IntPtr
alljoyn_aboutdatalistener = IntPtr
class alljoyn_aboutdatalistener_callbacks(Structure):
    about_datalistener_getaboutdata: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener_getaboutdata_ptr
    about_datalistener_getannouncedaboutdata: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_aboutdatalistener_getannouncedaboutdata_ptr
@winfunctype_pointer
def alljoyn_aboutdatalistener_getaboutdata_ptr(context: VoidPtr, msgArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, language: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype_pointer
def alljoyn_aboutdatalistener_getannouncedaboutdata_ptr(context: VoidPtr, msgArg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
alljoyn_abouticon = IntPtr
alljoyn_abouticonobj = IntPtr
alljoyn_abouticonproxy = IntPtr
alljoyn_aboutlistener = IntPtr
class alljoyn_aboutlistener_callback(Structure):
    about_listener_announced: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_about_announced_ptr
alljoyn_aboutobj = IntPtr
alljoyn_aboutobjectdescription = IntPtr
alljoyn_aboutproxy = IntPtr
alljoyn_applicationstate = Int32
NOT_CLAIMABLE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate = 0
CLAIMABLE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate = 1
CLAIMED: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate = 2
NEED_UPDATE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate = 3
alljoyn_applicationstatelistener = IntPtr
class alljoyn_applicationstatelistener_callbacks(Structure):
    state: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstatelistener_state_ptr
@winfunctype_pointer
def alljoyn_applicationstatelistener_state_ptr(busName: POINTER(SByte), publicKey: POINTER(SByte), applicationState: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_applicationstate, context: VoidPtr) -> Void: ...
alljoyn_authlistener = IntPtr
@winfunctype_pointer
def alljoyn_authlistener_authenticationcomplete_ptr(context: VoidPtr, authMechanism: win32more.Windows.Win32.Foundation.PSTR, peerName: win32more.Windows.Win32.Foundation.PSTR, success: Int32) -> Void: ...
class alljoyn_authlistener_callbacks(Structure):
    request_credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_requestcredentials_ptr
    verify_credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_verifycredentials_ptr
    security_violation: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_securityviolation_ptr
    authentication_complete: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_authenticationcomplete_ptr
@winfunctype_pointer
def alljoyn_authlistener_requestcredentials_ptr(context: VoidPtr, authMechanism: win32more.Windows.Win32.Foundation.PSTR, peerName: win32more.Windows.Win32.Foundation.PSTR, authCount: UInt16, userName: win32more.Windows.Win32.Foundation.PSTR, credMask: UInt16, credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> Int32: ...
@winfunctype_pointer
def alljoyn_authlistener_requestcredentialsasync_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, authMechanism: win32more.Windows.Win32.Foundation.PSTR, peerName: win32more.Windows.Win32.Foundation.PSTR, authCount: UInt16, userName: win32more.Windows.Win32.Foundation.PSTR, credMask: UInt16, authContext: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype_pointer
def alljoyn_authlistener_securityviolation_ptr(context: VoidPtr, status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, msg: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Void: ...
@winfunctype_pointer
def alljoyn_authlistener_verifycredentials_ptr(context: VoidPtr, authMechanism: win32more.Windows.Win32.Foundation.PSTR, peerName: win32more.Windows.Win32.Foundation.PSTR, credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials) -> Int32: ...
@winfunctype_pointer
def alljoyn_authlistener_verifycredentialsasync_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener, authMechanism: win32more.Windows.Win32.Foundation.PSTR, peerName: win32more.Windows.Win32.Foundation.PSTR, credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_credentials, authContext: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
class alljoyn_authlistenerasync_callbacks(Structure):
    request_credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_requestcredentialsasync_ptr
    verify_credentials: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_verifycredentialsasync_ptr
    security_violation: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_securityviolation_ptr
    authentication_complete: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_authlistener_authenticationcomplete_ptr
alljoyn_autopinger = IntPtr
@winfunctype_pointer
def alljoyn_autopinger_destination_found_ptr(context: VoidPtr, group: win32more.Windows.Win32.Foundation.PSTR, destination: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def alljoyn_autopinger_destination_lost_ptr(context: VoidPtr, group: win32more.Windows.Win32.Foundation.PSTR, destination: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
alljoyn_busattachment = IntPtr
@winfunctype_pointer
def alljoyn_busattachment_joinsessioncb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, sessionId: UInt32, opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_busattachment_setlinktimeoutcb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, timeout: UInt32, context: VoidPtr) -> Void: ...
alljoyn_buslistener = IntPtr
@winfunctype_pointer
def alljoyn_buslistener_bus_disconnected_ptr(context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_bus_prop_changed_ptr(context: VoidPtr, prop_name: win32more.Windows.Win32.Foundation.PSTR, prop_value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_bus_stopping_ptr(context: VoidPtr) -> Void: ...
class alljoyn_buslistener_callbacks(Structure):
    listener_registered: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_listener_registered_ptr
    listener_unregistered: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_listener_unregistered_ptr
    found_advertised_name: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_found_advertised_name_ptr
    lost_advertised_name: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_lost_advertised_name_ptr
    name_owner_changed: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_name_owner_changed_ptr
    bus_stopping: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_bus_stopping_ptr
    bus_disconnected: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_bus_disconnected_ptr
    property_changed: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_buslistener_bus_prop_changed_ptr
@winfunctype_pointer
def alljoyn_buslistener_found_advertised_name_ptr(context: VoidPtr, name: win32more.Windows.Win32.Foundation.PSTR, transport: UInt16, namePrefix: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_listener_registered_ptr(context: VoidPtr, bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busattachment) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_listener_unregistered_ptr(context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_lost_advertised_name_ptr(context: VoidPtr, name: win32more.Windows.Win32.Foundation.PSTR, transport: UInt16, namePrefix: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def alljoyn_buslistener_name_owner_changed_ptr(context: VoidPtr, busName: win32more.Windows.Win32.Foundation.PSTR, previousOwner: win32more.Windows.Win32.Foundation.PSTR, newOwner: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
alljoyn_busobject = IntPtr
class alljoyn_busobject_callbacks(Structure):
    property_get: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_prop_get_ptr
    property_set: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_prop_set_ptr
    object_registered: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_object_registration_ptr
    object_unregistered: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject_object_registration_ptr
class alljoyn_busobject_methodentry(Structure):
    member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member)
    method_handler: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagereceiver_methodhandler_ptr
@winfunctype_pointer
def alljoyn_busobject_object_registration_ptr(context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_busobject_prop_get_ptr(context: VoidPtr, ifcName: win32more.Windows.Win32.Foundation.PSTR, propName: win32more.Windows.Win32.Foundation.PSTR, val: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype_pointer
def alljoyn_busobject_prop_set_ptr(context: VoidPtr, ifcName: win32more.Windows.Win32.Foundation.PSTR, propName: win32more.Windows.Win32.Foundation.PSTR, val: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
class alljoyn_certificateid(Structure):
    serial: POINTER(Byte)
    serialLen: UIntPtr
    issuerPublicKey: POINTER(SByte)
    issuerAki: POINTER(Byte)
    issuerAkiLen: UIntPtr
class alljoyn_certificateidarray(Structure):
    count: UIntPtr
    ids: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_certificateid)
alljoyn_claimcapability_masks = Int32
CAPABLE_ECDHE_NULL: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_claimcapability_masks = 1
CAPABLE_ECDHE_ECDSA: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_claimcapability_masks = 4
CAPABLE_ECDHE_SPEKE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_claimcapability_masks = 8
alljoyn_claimcapabilityadditionalinfo_masks = Int32
PASSWORD_GENERATED_BY_SECURITY_MANAGER: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_claimcapabilityadditionalinfo_masks = 1
PASSWORD_GENERATED_BY_APPLICATION: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_claimcapabilityadditionalinfo_masks = 2
alljoyn_credentials = IntPtr
alljoyn_interfacedescription = IntPtr
class alljoyn_interfacedescription_member(Structure):
    iface: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription
    memberType: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype
    name: win32more.Windows.Win32.Foundation.PSTR
    signature: win32more.Windows.Win32.Foundation.PSTR
    returnSignature: win32more.Windows.Win32.Foundation.PSTR
    argNames: win32more.Windows.Win32.Foundation.PSTR
    internal_member: VoidPtr
class alljoyn_interfacedescription_property(Structure):
    name: win32more.Windows.Win32.Foundation.PSTR
    signature: win32more.Windows.Win32.Foundation.PSTR
    access: Byte
    internal_property: VoidPtr
alljoyn_interfacedescription_securitypolicy = Int32
AJ_IFC_SECURITY_INHERIT: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_securitypolicy = 0
AJ_IFC_SECURITY_REQUIRED: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_securitypolicy = 1
AJ_IFC_SECURITY_OFF: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_securitypolicy = 2
@winfunctype_pointer
def alljoyn_interfacedescription_translation_callback_ptr(sourceLanguage: win32more.Windows.Win32.Foundation.PSTR, targetLanguage: win32more.Windows.Win32.Foundation.PSTR, sourceText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
alljoyn_keystore = IntPtr
alljoyn_keystorelistener = IntPtr
@winfunctype_pointer
def alljoyn_keystorelistener_acquireexclusivelock_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
class alljoyn_keystorelistener_callbacks(Structure):
    load_request: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_loadrequest_ptr
    store_request: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_storerequest_ptr
@winfunctype_pointer
def alljoyn_keystorelistener_loadrequest_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener, keyStore: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystore) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype_pointer
def alljoyn_keystorelistener_releaseexclusivelock_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener) -> Void: ...
@winfunctype_pointer
def alljoyn_keystorelistener_storerequest_ptr(context: VoidPtr, listener: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener, keyStore: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystore) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
class alljoyn_keystorelistener_with_synchronization_callbacks(Structure):
    load_request: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_loadrequest_ptr
    store_request: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_storerequest_ptr
    acquire_exclusive_lock: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_acquireexclusivelock_ptr
    release_exclusive_lock: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_keystorelistener_releaseexclusivelock_ptr
class alljoyn_manifestarray(Structure):
    count: UIntPtr
    xmls: POINTER(POINTER(SByte))
alljoyn_message = IntPtr
@winfunctype_pointer
def alljoyn_messagereceiver_methodhandler_ptr(bus: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_busobject, member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member), message: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Void: ...
@winfunctype_pointer
def alljoyn_messagereceiver_replyhandler_ptr(message: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_messagereceiver_signalhandler_ptr(member: POINTER(win32more.Windows.Win32.Devices.AllJoyn.alljoyn_interfacedescription_member), srcPath: win32more.Windows.Win32.Foundation.PSTR, message: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_message) -> Void: ...
alljoyn_messagetype = Int32
ALLJOYN_MESSAGE_INVALID: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype = 0
ALLJOYN_MESSAGE_METHOD_CALL: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype = 1
ALLJOYN_MESSAGE_METHOD_RET: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype = 2
ALLJOYN_MESSAGE_ERROR: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype = 3
ALLJOYN_MESSAGE_SIGNAL: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_messagetype = 4
alljoyn_msgarg = IntPtr
alljoyn_observer = IntPtr
@winfunctype_pointer
def alljoyn_observer_object_discovered_ptr(context: VoidPtr, proxyref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> Void: ...
@winfunctype_pointer
def alljoyn_observer_object_lost_ptr(context: VoidPtr, proxyref: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject_ref) -> Void: ...
alljoyn_observerlistener = IntPtr
class alljoyn_observerlistener_callback(Structure):
    object_discovered: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer_object_discovered_ptr
    object_lost: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_observer_object_lost_ptr
alljoyn_permissionconfigurationlistener = IntPtr
class alljoyn_permissionconfigurationlistener_callbacks(Structure):
    factory_reset: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener_factoryreset_ptr
    policy_changed: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener_policychanged_ptr
    start_management: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener_startmanagement_ptr
    end_management: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_permissionconfigurationlistener_endmanagement_ptr
@winfunctype_pointer
def alljoyn_permissionconfigurationlistener_endmanagement_ptr(context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_permissionconfigurationlistener_factoryreset_ptr(context: VoidPtr) -> win32more.Windows.Win32.Devices.AllJoyn.QStatus: ...
@winfunctype_pointer
def alljoyn_permissionconfigurationlistener_policychanged_ptr(context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_permissionconfigurationlistener_startmanagement_ptr(context: VoidPtr) -> Void: ...
alljoyn_permissionconfigurator = IntPtr
alljoyn_pinglistener = IntPtr
class alljoyn_pinglistener_callback(Structure):
    destination_found: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger_destination_found_ptr
    destination_lost: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_autopinger_destination_lost_ptr
alljoyn_proxybusobject = IntPtr
@winfunctype_pointer
def alljoyn_proxybusobject_listener_getallpropertiescb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, values: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_proxybusobject_listener_getpropertycb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, value: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_proxybusobject_listener_introspectcb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_proxybusobject_listener_propertieschanged_ptr(obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, ifaceName: win32more.Windows.Win32.Foundation.PSTR, changed: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, invalidated: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_msgarg, context: VoidPtr) -> Void: ...
@winfunctype_pointer
def alljoyn_proxybusobject_listener_setpropertycb_ptr(status: win32more.Windows.Win32.Devices.AllJoyn.QStatus, obj: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_proxybusobject, context: VoidPtr) -> Void: ...
alljoyn_proxybusobject_ref = IntPtr
alljoyn_securityapplicationproxy = IntPtr
alljoyn_sessionlistener = IntPtr
class alljoyn_sessionlistener_callbacks(Structure):
    session_lost: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener_sessionlost_ptr
    session_member_added: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener_sessionmemberadded_ptr
    session_member_removed: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlistener_sessionmemberremoved_ptr
@winfunctype_pointer
def alljoyn_sessionlistener_sessionlost_ptr(context: VoidPtr, sessionId: UInt32, reason: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason) -> Void: ...
@winfunctype_pointer
def alljoyn_sessionlistener_sessionmemberadded_ptr(context: VoidPtr, sessionId: UInt32, uniqueName: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def alljoyn_sessionlistener_sessionmemberremoved_ptr(context: VoidPtr, sessionId: UInt32, uniqueName: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
alljoyn_sessionlostreason = Int32
ALLJOYN_SESSIONLOST_INVALID: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 0
ALLJOYN_SESSIONLOST_REMOTE_END_LEFT_SESSION: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 1
ALLJOYN_SESSIONLOST_REMOTE_END_CLOSED_ABRUPTLY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 2
ALLJOYN_SESSIONLOST_REMOVED_BY_BINDER: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 3
ALLJOYN_SESSIONLOST_LINK_TIMEOUT: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 4
ALLJOYN_SESSIONLOST_REASON_OTHER: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionlostreason = 5
alljoyn_sessionopts = IntPtr
alljoyn_sessionportlistener = IntPtr
@winfunctype_pointer
def alljoyn_sessionportlistener_acceptsessionjoiner_ptr(context: VoidPtr, sessionPort: UInt16, joiner: win32more.Windows.Win32.Foundation.PSTR, opts: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionopts) -> Int32: ...
class alljoyn_sessionportlistener_callbacks(Structure):
    accept_session_joiner: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener_acceptsessionjoiner_ptr
    session_joined: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_sessionportlistener_sessionjoined_ptr
@winfunctype_pointer
def alljoyn_sessionportlistener_sessionjoined_ptr(context: VoidPtr, sessionPort: UInt16, id: UInt32, joiner: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
alljoyn_typeid = Int32
ALLJOYN_INVALID: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 0
ALLJOYN_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 97
ALLJOYN_BOOLEAN: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 98
ALLJOYN_DOUBLE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 100
ALLJOYN_DICT_ENTRY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 101
ALLJOYN_SIGNATURE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 103
ALLJOYN_HANDLE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 104
ALLJOYN_INT32: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 105
ALLJOYN_INT16: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 110
ALLJOYN_OBJECT_PATH: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 111
ALLJOYN_UINT16: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 113
ALLJOYN_STRUCT: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 114
ALLJOYN_STRING: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 115
ALLJOYN_UINT64: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 116
ALLJOYN_UINT32: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 117
ALLJOYN_VARIANT: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 118
ALLJOYN_INT64: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 120
ALLJOYN_BYTE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 121
ALLJOYN_STRUCT_OPEN: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 40
ALLJOYN_STRUCT_CLOSE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 41
ALLJOYN_DICT_ENTRY_OPEN: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 123
ALLJOYN_DICT_ENTRY_CLOSE: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 125
ALLJOYN_BOOLEAN_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 25185
ALLJOYN_DOUBLE_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 25697
ALLJOYN_INT32_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 26977
ALLJOYN_INT16_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 28257
ALLJOYN_UINT16_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 29025
ALLJOYN_UINT64_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 29793
ALLJOYN_UINT32_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 30049
ALLJOYN_INT64_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 30817
ALLJOYN_BYTE_ARRAY: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 31073
ALLJOYN_WILDCARD: win32more.Windows.Win32.Devices.AllJoyn.alljoyn_typeid = 42


make_ready(__name__)
